<?php

namespace Survey\Organisation\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Survey\Organisation\Http\Requests\FileRequest;
use Survey\Organisation\Interfaces\FileRepositoryInterface;
use Survey\Organisation\Models\File;
use Survey\Organisation\Forms\File as Form;

/**
 * APIController  class for file.
 */
class FileAPIController extends BaseController
{

    /**
     * Initialize file resource controller.
     *
     * @param type FileRepositoryInterface $file
     *
     * @return null
     */
    public function __construct(FileRepositoryInterface $file)
    {
        parent::__construct();
        $this->repository = $file;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Survey\Organisation\Repositories\Criteria\FileResourceCriteria::class);
    }

    /**
     * Display a list of file.
     *
     * @return Response
     */
    public function index(FileRequest $request)
    {
        return $this->repository
            ->setPresenter(\Survey\Organisation\Repositories\Presenter\FilePresenter::class)
            ->paginate();
    }

    /**
     * Display file.
     *
     * @param Request $request
     * @param Model   $file
     *
     * @return Response
     */
    public function show(FileRequest $request, File $file)
    {
        return $file->setPresenter(\Survey\Organisation\Repositories\Presenter\FileListPresenter::class);
        ;
    }

    /**
     * Create new file.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(FileRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('organisation::file.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('organisation/file/' . $file->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('organisation/file');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the file.
     *
     * @param Request $request
     * @param Model   $file
     *
     * @return Response
     */
    public function update(FileRequest $request, File $file)
    {
        try {
            $data = $request->all();

            $file->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('organisation::file.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('organisation/file/' . $file->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('organisation/file/' . $file->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the file.
     *
     * @param Model   $file
     *
     * @return Response
     */
    public function destroy(FileRequest $request, File $file)
    {
        try {
            $file->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('organisation::file.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('organisation/file/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('organisation/file/' . $file->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
