<?php

namespace Survey\Organisation\Policies;

use Litepie\User\Contracts\UserPolicy;
use Survey\Organisation\Models\Hierarchy;

class HierarchyPolicy
{

    /**
     * Determine if the given user can view the hierarchy.
     *
     * @param UserPolicy $user
     * @param Hierarchy $hierarchy
     *
     * @return bool
     */
    public function view(UserPolicy $user, Hierarchy $hierarchy)
    {
        if ($user->canDo('organisation.hierarchy.view') && $user->isAdmin()) {
            return true;
        }

        return $hierarchy->user_id == user_id() && $hierarchy->user_type == user_type();
    }

    /**
     * Determine if the given user can create a hierarchy.
     *
     * @param UserPolicy $user
     * @param Hierarchy $hierarchy
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('organisation.hierarchy.create');
    }

    /**
     * Determine if the given user can update the given hierarchy.
     *
     * @param UserPolicy $user
     * @param Hierarchy $hierarchy
     *
     * @return bool
     */
    public function update(UserPolicy $user, Hierarchy $hierarchy)
    {
        if ($user->canDo('organisation.hierarchy.edit') && $user->isAdmin()) {
            return true;
        }

        return $hierarchy->user_id == user_id() && $hierarchy->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given hierarchy.
     *
     * @param UserPolicy $user
     * @param Hierarchy $hierarchy
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Hierarchy $hierarchy)
    {
        return $hierarchy->user_id == user_id() && $hierarchy->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given hierarchy.
     *
     * @param UserPolicy $user
     * @param Hierarchy $hierarchy
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Hierarchy $hierarchy)
    {
        if ($user->canDo('organisation.hierarchy.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given hierarchy.
     *
     * @param UserPolicy $user
     * @param Hierarchy $hierarchy
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Hierarchy $hierarchy)
    {
        if ($user->canDo('organisation.hierarchy.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
